@@ -11,20 +11,17 @@ under the terms of the Creative Commons Attribution-NonCommercial
 The code is licensed under the MIT license.
 """
 
-from typing import Union
+from collections.abc import Callable
+from typing import Dict, List, Union
 import pandas as pd
 from meteostat.enumerations.granularity import Granularity
-from meteostat.core.cache import get_local_file_path, file_in_cache
-from meteostat.core.loader import processing_handler, load_handler
-from meteostat.utilities.mutations import localize, filter_time, adjust_temp
-from meteostat.utilities.validations import validate_series
+from meteostat.core.loader import processing_handler
+from meteostat.utilities.mutations import adjust_temp
 from meteostat.utilities.aggregations import weighted_average
-from meteostat.utilities.endpoint import generate_endpoint_path
 from meteostat.interface.base import Base
 
 
 class MeteoData(Base):
-
     """
     A parent class for both time series and
     climate normals data
@@ -36,73 +33,66 @@ class MeteoData(Base):
     # The data frame
     _data: pd.DataFrame = pd.DataFrame()
 
-    def _load_data(self, station: str, year: Union[int, None] = None) -> None:
+    @property
+    def _raw_columns(self) -> List[str]:
         """
-        Load file for a single station from Meteostat
+        Get the list of raw data columns, excluding any dicts with callable values
         """
-
-        # File name
-        file = generate_endpoint_path(self.granularity, station, year)
-
-        # Get local file path
-        path = get_local_file_path(self.cache_dir, self.cache_subdir, file)
-
-        # Check if file in cache
-        if self.max_age > 0 and file_in_cache(path, self.max_age):
-
-            # Read cached data
-            df = pd.read_pickle(path)
-
-        else:
-
-            # Get data from Meteostat
-            df = load_handler(
-                self.endpoint, file, self._columns, self._types, self._parse_dates
+        return [
+            list(col.values())[0] if isinstance(col, dict) else col
+            for col in self._columns
+            if not (
+                isinstance(col, dict)
+                and (
+                    isinstance(list(col.values())[0], Callable)
+                    or list(col.values())[0] is None
+                )
             )
+        ]
 
-            # Validate and prepare data for further processing
-            if self.granularity == Granularity.NORMALS and df.index.size > 0:
-                # Add weather station ID
-                # pylint: disable=unsupported-assignment-operation
-                df["station"] = station
+    @property
+    def _processed_columns(self) -> List[str]:
+        """
+        Get the list of processed data columns, excluding any dicts with callable values
+        """
+        return [
+            list(col.keys())[0] if isinstance(col, dict) else col
+            for col in self._columns[self._first_met_col :]
+        ]
 
-                # Set index
-                df = df.set_index(["station", "start", "end", "month"])
+    @property
+    def _renamed_columns(self) -> Dict[str, str]:
+        """
+        Get the dict of renamed data columns, including `_source` suffixes
+        """
+        return {
+            new_key: new_val
+            for d in self._columns
+            if isinstance(d, dict)
+            for k, v in d.items()
+            if not isinstance(v, Callable)
+            for new_key, new_val in ((v, k), (f"{v}_source", f"{k}_source"))
+        }
 
-            else:
-                df = validate_series(df, station)
-
-            # Save as Pickle
-            if self.max_age > 0:
-                df.to_pickle(path)
-
-        # Localize time column
-        if (
-            self.granularity == Granularity.HOURLY
-            and self._timezone is not None
-            and len(df.index) > 0
-        ):
-            df = localize(df, self._timezone)
-
-        # Filter time period and append to DataFrame
-        # pylint: disable=no-else-return
-        if self.granularity == Granularity.NORMALS and df.index.size > 0 and self._end:
-            # Get time index
-            end = df.index.get_level_values("end")
-            # Filter & return
-            return df.loc[end == self._end]
-        elif not self.granularity == Granularity.NORMALS:
-            df = filter_time(df, self._start, self._end)
-
-        # Return
-        return df
+    @property
+    def _virtual_columns(self) -> Dict[str, str]:
+        """
+        Get the dict of virtual data columns
+        """
+        return {
+            k: v
+            for d in self._columns
+            if isinstance(d, dict)
+            for k, v in d.items()
+            if isinstance(v, Callable)
+        }
 
     def _get_datasets(self) -> list:
         """
         Get list of datasets
         """
 
-        if self.granularity == Granularity.HOURLY and self.chunked:
+        if self.granularity in (Granularity.HOURLY, Granularity.DAILY):
             datasets = [
                 (str(station), year)
                 for station in self._stations
@@ -119,7 +109,6 @@ class MeteoData(Base):
         """
 
         if len(self._stations) > 0:
-
             # Get list of datasets
             datasets = self._get_datasets()
 
@@ -140,12 +129,10 @@ class MeteoData(Base):
         """
 
         if self._stations.size == 0 or self._data.size == 0:
-            return None
+            return
 
         if method == "nearest":
-
             if adapt_temp:
-
                 # Join elevation of involved weather stations
                 data = self._data.join(stations["elevation"], on="station")
 
@@ -156,7 +143,6 @@ class MeteoData(Base):
                 data = data.drop("elevation", axis=1).round(1)
 
             else:
-
                 data = self._data
 
             if self.granularity == Granularity.NORMALS:
@@ -168,7 +154,6 @@ class MeteoData(Base):
                 ).agg("first")
 
         else:
-
             # Join score and elevation of involved weather stations
             data = self._data.join(stations[["score", "elevation"]], on="station")
 
