@@ -9,6 +9,7 @@ The code is licensed under the MIT license.
 """
 
 from copy import copy
+import numpy as np
 from meteostat.core.warn import warn
 
 
@@ -18,17 +19,26 @@ def interpolate(self, limit: int = 3):
     """
 
     if self.count() > 0 and not self._data.isnull().values.all():
-
         # Create temporal instance
         temp = copy(self)
 
+        # Convert to float64
+        temp._data = temp._data.astype("float64")
+
         # Apply interpolation
-        temp._data = temp._data.groupby("station").apply(
+        temp._data = temp._data.groupby("station", group_keys=False).apply(
             lambda group: group.interpolate(
-                method="linear", limit=limit, limit_direction="both", axis=0
+                method="linear",
+                limit=limit,
+                limit_direction="both",
+                axis=0,
+                fill_value=np.nan,
             )
         )
 
+        # Convert to original type
+        temp._data = temp._data.astype("Float64")
+
         # Return class instance
         return temp
 
