@@ -52,8 +52,18 @@ def adjust_temp(df: pd.DataFrame, alt: int):
     # Adjust values for all temperature-like data
     for col_name in temp_like:
         if col_name in df.columns:
-            df.loc[df[col_name] != np.NaN, col_name] = df[col_name] + (
+            df.loc[df[col_name] != np.nan, col_name] = df[col_name] + (
                 temp_diff * ((df["elevation"] - alt) / 100)
             )
 
     return df
+
+
+def calculate_dwpt(df: pd.DataFrame, col: str) -> pd.DataFrame:
+    """
+    Calculate dew point temperature
+    """
+    df[col] = df["temp"] - ((100 - df["rhum"]) / 5)
+    df[f"{col}_flag"] = df[["temp_flag", "rhum_flag"]].max(axis=1, skipna=True)
+
+    return df
